@@ -248,7 +248,17 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
 
         r = response.json()
-        return pd.DataFrame(r['data'])
+        codes = []
+        columns = []
+        for col in response["schema"]:
+            codes.append(col["code"])
+            if col["name"] != '':
+                columns.append(col["name"])
+            else:
+                columns.append(col["code"])
+        df = pd.DataFrame(columns=codes, data=response["data"])
+        df.columns = columns
+        return df
 
 
     def update_dataset_name(self, dataset_slug, dataset_name):
@@ -317,7 +327,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = response.json()
         return pd.DataFrame(r['payload']['data'])
 
-    def load_dataset(self, dataset_slug, aliases:list=[], filters:list=[]):
+    def load_dataset(self, dataset_slug, aliases:list=[], filters:list=[], limit=50):
 
         '''
         str : dataset_slug ("my_dataset")
@@ -375,7 +385,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
             "orderBy": None,
             "relationships": None,
             "where": filters,
-            "limit": 100
+            "limit": limit
         }
         fields = []
         for alias in aliases:
@@ -683,7 +693,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         logging.info("DATACARD {} CREATED".format(slug))
 
-        return Insight_Definition(self._env, self._token, definition)
+        return Insight_Definition(self._env, self._token, self._slug, definition)
 
     def get_datacard(self, slug):
 
@@ -698,7 +708,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r.raise_for_status()
 
         definition = r.json()
-        return Insight_Definition(self._env, self._token, definition)
+        return Insight_Definition(self._env, self._token, self._slug, definition)
 
     def create_channel(self, name, icon='https://storage.googleapis.com/askdata/smartfeed/icons/Channel@2x.png',
                        visibility='PRIVATE'):
