@@ -6,6 +6,7 @@ import pandas as pd
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 from typing import TYPE_CHECKING
+from IPython.display import Image, display, HTML
 if TYPE_CHECKING:
     from askdata.askdata_client import Askdata
 
@@ -25,10 +26,11 @@ with open(yaml_path, 'r') as file:
 class Insight_Definition:
 
 
-    def __init__(self, env:str, token, defintion):
+    def __init__(self, env:str, token, agent_slug, defintion):
 
         self.definition_id = defintion["id"]
         self.agent_id = defintion["agentId"]
+        self.agent_slug = agent_slug
         self.collection_id = defintion["collectionId"]
         self.name = defintion["name"]
         self.slug = defintion["slug"]
@@ -40,15 +42,15 @@ class Insight_Definition:
         if env.lower() == 'dev':
             self._base_url_askdata = url_list['BASE_URL_ASKDATA_DEV']
             self.smart_insight_url = url_list['BASE_URL_INSIGHT_DEV']
-            self.app_url = "https://app-dev.askdata.com/"
+            self.app_url = "https://app-dev.askdata.com"
         if env.lower() == 'qa':
             self._base_url_askdata = url_list['BASE_URL_ASKDATA_QA']
             self.smart_insight_url = url_list['BASE_URL_INSIGHT_QA']
-            self.app_url = "https://app-qa.askdata.com/"
+            self.app_url = "https://app-qa.askdata.com"
         if env.lower() == 'prod':
             self._base_url_askdata = url_list['BASE_URL_ASKDATA_PROD']
             self.smart_insight_url = url_list['BASE_URL_INSIGHT_PROD']
-            self.app_url = "https://app.askdata.com/"
+            self.app_url = "https://app.askdata.com"
 
 
     def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[]):
@@ -131,6 +133,77 @@ class Insight_Definition:
         r.raise_for_status()
         return r.json()
 
+    def display_card_img(self):
+        display(Image(data=self.__get_card_img()))
+
+
+    def download_card_img(self, image_path:str):
+        with open(image_path, 'wb') as f:
+            f.write(self.__get_card_img())
+
+
+    def get_card_url(self):
+        return self.__get_card__url()
+
+
+    def __get_card__url(self):
+
+        url = self.app_url + "/"+self.agent_slug+"/card/" + self.slug
+        return url
+
+    def preview(self):
+
+        url = self.app_url+"/card/"+self.__get_card_id()
+        display(HTML('<iframe src="'+url+'" height="300" width="300" title="'+self.slug+'"></iframe>'))
+
+    def __get_card_id(self):
+
+        url = self._base_url_askdata+"/smartfeed/agents/"+self.agent_id+"/insights/insightslug/"+self.slug
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.get(url=url, headers=headers)
+        r.raise_for_status()
+        cards = r.json()
+        for card in cards:
+            try:
+                if(card["insightSlug"]==self.slug):
+                    return card["id"]
+            except KeyError:
+                pass
+
+        logging.error("Card not found")
+        return None
+
+    def __get_card_img(self):
+
+        card_id = self.__get_card_id()
+
+        if(card_id != None):
+
+            url = self._base_url_askdata+"/smartinsight/insights/"+card_id+"/data?type=image"
+            s = requests.Session()
+            s.keep_alive = False
+            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+            s.mount('https://', HTTPAdapter(max_retries=retries))
+
+            headers = {
+                "Content-Type": "application/json",
+                "Authorization": "Bearer" + " " + self._token
+            }
+            r = s.get(url=url, headers=headers)
+            r.raise_for_status()
+            return r.content
+        else:
+            return None
+
+
     def __create_widget(self, position, widget_type):
 
         body = {"type": "widget", "position": position, "widgetType": widget_type}
